@@ -10,8 +10,8 @@ import re
 import os
 from os.path import join
 
-# do not include /build/ dir, *.egg-info dir and py[co] files
-EXCLUDE = re.compile(r'(^build|[^/]+\.egg-info|.*.py[co]$)')
+# do not include /build/ dir, /.*, *.egg-info dir and py[co] files
+EXCLUDE = re.compile(r'(^build|^\.[^/]+|[^/]+\.egg-info|.*.py[co]$)')
 
 def walk(top):
     files = []
